@@ -6,7 +6,9 @@ use warnings;
 
 use DBI;
 use Error qw(:try);
-use Helios::TheSchwartz;
+# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
+use Helios::TS;
+use Helios::TS::Job;
 use Helios::ObjectDriver::DBI;
 
 require XML::Simple;
@@ -14,7 +16,7 @@ require XML::Simple;
 use Helios::Error;
 use Helios::JobHistory;
 
-our $VERSION = '2.601_3670';
+our $VERSION = '2.801_3270';
 
 our $D_OD_RETRIES = 3;
 our $D_OD_RETRY_INTERVAL = 5;
@@ -33,6 +35,13 @@ our $D_OD_RETRY_INTERVAL = 5;
 # [LH] [2013-09-07] new(): changed to check to see if TheSchwartz::Job object 
 # to new() has an array in arg(), and throw an exception if it doesn't.
 # (It always should, but [RT79690] is preventing that in a tiny number of cases.) 
+# [LH] [2013-10-18] Replaced calls to Helios::TheSchwartz and TheSchwartz::Job
+# with Helios::TS and Helios::TS::Job.
+# [LH] [2013-10-28] Added set/getArgString(), set/getJobType(), 
+# set/getJobtypeid() methods; set/getArgXML(), set/getFuncname(), 
+# set/getFuncid() will be deprecated in Helios 3.x.  Changed POD to document 
+# the new functions.  
+# [LH] [2014-08-10] Added get/setPriority() methods.
 
 
 =head1 NAME
@@ -50,18 +59,18 @@ jobs in the Helios system.
 These accessors allow access to information about an instantiated Helios::Job 
 object:
 
- debug()          whether Debug Mode is enabled or not
- get/setConfig()  Helios configuration passed by the system to the job object
- get/setArgs()    hashref of the job's arguments (interpreted from the arg XML)
- get/setArgXML()  the raw XML of the job arguments
+ debug()             whether Debug Mode is enabled or not
+ get/setConfig()     Helios configuration passed by the system to the job object
+ get/setArgs()       hashref of the job's arguments (interpreted from the arg string)
+ get/setArgString()  the raw XML of the job arguments
 
 Several accessors are pass-through accessors to access values in the 
 underlying TheSchwartz::Job object
  
  get/setJobid()         jobid of the job in the job queue
  get/setFailures()      number of previous failures of the job before current run
- get/setFuncid()        funcid value of the job (maps to funcname in Helios db)
- get/setFuncname()      funcname value of the job (maps to funcid in Helios db)
+ get/setJobtypeid()     jobtypeid value of the job 
+ get/setJobType()       jobtype name of the job
  get/setUniqkey()       uniqkey value of the job (see TheSchwartz documentation)
  get/setRunAfter()      current run_after value of the job
  get/setGrabbedUntil()  current grabbed_until value of the job
@@ -125,6 +134,28 @@ sub job { my $self = shift; @_ ? $self->{job} = shift : $self->{job}; }
 sub setArgXML { $_[0]->{argxml} = $_[1]; }
 sub getArgXML { return $_[0]->{argxml}; }
 
+# BEGIN CODE Copyright (C) 2013 by Logical Helion, LLC.
+sub setArgString { setArgXML(@_) }
+sub getArgString { getArgXML(@_) }
+
+sub setJobType { setFuncname(@_) }
+sub getJobType { getFuncname(@_) }
+
+sub setJobtypeid { setFuncid(@_) }
+sub getJobtypeid { getFuncid(@_) }
+# END CODE Copyright (C) 2013 by Logical Helion, LLC.
+
+# BEGIN CODE Copyright (C) 2014 by Logical Helion, LLC.
+sub setPriority {
+	my $self = shift;
+	my $p = shift;
+	$self->job()->priority($p);
+}
+sub getPriority {
+	my $self = shift;
+	$self->job()->priority();
+}
+# END CODE Copyright (C) 2014 by Logical Helion, LLC.
 
 =head1 METHODS
 
@@ -140,7 +171,8 @@ sub new {
 	bless $self, $class;
 
 	# init fields
-	if ( defined($_[0]) && ref($_[0]) && $_[0]->isa('TheSchwartz::Job') ) {
+	# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
+	if ( defined($_[0]) && ref($_[0]) && $_[0]->isa('Helios::TS::Job') ) {
 		$self->job($_[0]);
 # BEGIN CODE COPYRIGHT (C) 2013 LOGICAL HELION, LLC.
 # [LH] [2013-09-07] new(): changed to check to see if TheSchwartz::Job object 
@@ -154,7 +186,8 @@ sub new {
 		}
 # END CODE COPYRIGHT (C) 2013 LOGICAL HELION, LLC.
 	} else {
-		my $schwartz_job = TheSchwartz::Job->new(@_);
+		# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
+		my $schwartz_job = Helios::TS::Job->new(@_);
 		$self->job($schwartz_job);
 	}
 
@@ -444,8 +477,8 @@ error if it fails.
 Before a job can be successfully submitted, the following must be set first:
 
  $job->setConfig($configHash);
- $job->setArgXML($xmlstring);
- $job->setFuncname($servicename);
+ $job->setArgString($xmlstring);
+ $job->setJobType($servicename);
 
 So, for example, to submit a Helios::TestService to the Helios system, you need 
 to do the following:
@@ -465,8 +498,8 @@ to do the following:
  # once you have the config, you can set up the Helios::Job
  my $job = Helios::Job->new();
  $job->setConfig($config);
- $job->setFuncname('Helios::TestService');
- $job->setArgXML();
+ $job->setJobType('Helios::TestService');
+ $job->setArgString($jobxml);
  
  # then submit the job (this will throw an exception if something goes wrong)
  my $jobid = $job->submit();
@@ -478,6 +511,8 @@ if they encounter errors, so a safer example would catch them:
  use Helios::Service;
  use Helios::Job;
 
+ my $jobxml = "<job><params><string1>This is a test</string1/params>/job>";
+
  my $srv = Helios::Service->new();
  eval {
  	$srv->prep();
@@ -492,8 +527,8 @@ if they encounter errors, so a safer example would catch them:
  # once you have the config, you can set up the Helios::Job
  my $job = Helios::Job->new();
  $job->setConfig($config);
- $job->setFuncname('Helios::TestService');
- $job->setArgXML();
+ $job->setJobType('Helios::TestService');
+ $job->setArgString($jobxml);
  
  # then submit the job (this will throw an exception if something goes wrong)
  my $jobid;
@@ -526,7 +561,8 @@ sub submit {
 
 	my $args = [ $params ];
 
-	my $client = Helios::TheSchwartz->new( databases => $databases, verbose => 1 );
+	# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
+	my Helios::TS $client = Helios::TS->new( databases => $databases, verbose => 1 );
 	my $sjh = $client->insert($job_class, $args);
 	$self->setJobid($sjh->jobid);
 	return $sjh->jobid;
@@ -632,7 +668,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<Helios>, L<Helios::Service>, L<TheSchwartz::Job>, L<XML::Simple>
+L<Helios::Service>, L<Helios::TS>, L<Helios::TS::Job>, L<XML::Simple>
 
 =head1 AUTHOR
 
@@ -645,6 +681,9 @@ Copyright (C) 2008 by CEB Toolbox, Inc.
 Portions of this software, where noted, are
 Copyright (C) 2012 by Andrew Johnson.
 
+Portions of this software, where noted, are
+Copyright (C) 2013-4 by Logical Helion, LLC.
+
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.0 or,
 at your option, any later version of Perl 5 you may have available.
